@@ -82,8 +82,8 @@ higher-level logic remains application-specific. Especially the mode of
 operation, ad-hoc or managed with a Discovery Proxy, depends on the application
 deployment and WS-Discovery support requirements.
 
-The following assumptions are made. A Client is an endpoint that searches for
-Target Service(s). A Target Service (TS) is and endpoint that makes itself
+The following assumptions are made. A Client (C) is an endpoint that searches for
+Target Service(s). A Target Service (TS) is a service endpoint that makes itself
 available for discovery. A Discovery Proxy (DP) is an endpoint that facilitates
 discovery of Target Services by Clients. The interfaces defined in the wsdd
 library can be used to implement Client, Target Service, and Discovery Proxy
@@ -139,9 +139,6 @@ periodically polling the port as shown:
       soap_print_fault(soap, stderr);
       exit(0);
     }
-
-    soap_wsdd_listen(soap, -1000); // listen for messages for 1 ms
-
     soap_wsdd_listen(soap, -1000); // listen for messages for 1 ms
     ...
 @endcode
@@ -359,8 +356,6 @@ separately on wsdd.h (or wsdd5.h or wsdd10.h for WS-Discovery 1.0) by:
 
     soapcpp2 -a -L -pwsdd -Iimport import/wsdd.h
     
-This generates wsddService.cpp and wsddClient.cpp, which should be compiled together with the rest of your project code. Then change wsddapi.h to use `#include "wsddH.h"`.
-
 Now with this approach you must chain the service operations at the server side
 as follows:
 
@@ -373,6 +368,12 @@ as follows:
 where the `service` object is an instance of the application services generated
 by soapcpp2 `-j`.
 
+Then compile the generated wsddClient.cpp file with the macro
+`-DSOAP_H_FILE=wsddH.h` to specify that `wsddH.h` should be used instead of
+`soapH.h.
+
+To combine WS-Security with WS-Discovery, please see the next section.
+
 @section wsdd_6 Miscellaneous
 
 You must generate client-side operations that the WSDD library expects to be
@@ -380,13 +381,31 @@ linked with, by executing:
 
     soapcpp2 -a -L -pwsdd -Iimport import/wsdd.h
 
-Then change wsddapi.h to use `#include "wsddH.h"` and compile and link the
-generated wsddClient.cpp code with your project.
+Then compile the generated wsddClient.cpp file with the macro
+`-DSOAP_H_FILE=wsddH.h` to specify that `wsddH.h` should be used instead of
+`soapH.h.
+
+If WS-Security is used with WS-Discovery, then create a file `imports.h` with
+the following two lines:
+
+@code
+    // file: imports.h
+    #import "wsdd.h" // or wsdd10.h, wsdd5.h
+    #import "wsse.h"
+@endcode
+
+Then execute:
+
+    soapcpp2 -a -L -pwsdd -Iimport imports.h
+
+This generates wsddC.cpp and wsddClient.cpp, which should be compiled together
+with plugin/wsddapi.c, plugin/wsseapi.c, plugin/mecevp.c, and plugin/smdevp.c.
+All files should be compiled with `-DSOAP_H_FILE=wsddH.h`, i.e. macro
+`SOAP_H_FILE` set to `wsddH.h`.  WS-Security requires OpenSSL and linkage with
+libssl and libcrypto.
 
 For server-side projects, also compile and link the generated wsddServer.cpp
-code.
-
-You will need to implement the @ref wsdd_2.
+code.  You will also need to implement the @ref wsdd_2.
 
 Because WS-Addressing may relay faults to a FaultTo service, when implementing
 a service you will also have to define a SOAP Fault service operation to accept
@@ -1346,7 +1365,7 @@ __wsdd__Bye(struct soap *soap, struct wsdd__ByeType *Bye)
 /******************************************************************************/
 
 static int
-soap_wsdd_http(struct soap *soap, const char *endpoint, const char *host, int port, const char *path, const char *action, size_t count)
+soap_wsdd_http(struct soap *soap, const char *endpoint, const char *host, int port, const char *path, const char *action, ULONG64 count)
 {
   (void)endpoint; (void)host; (void)port; (void)path; (void)action;
   return soap->fresponse(soap, SOAP_OK, count);
@@ -1403,7 +1422,7 @@ __wsdd__Probe(struct soap *soap, struct wsdd__ProbeType *Probe)
   else
   {
     int err;
-    int (*fpost)(struct soap*, const char*, const char*, int, const char*, const char*, size_t);
+    int (*fpost)(struct soap*, const char*, const char*, int, const char*, const char*, ULONG64);
     const char *MessageID = soap_wsa_rand_uuid(soap);
     const char *Action = SOAP_NAMESPACE_OF_wsdd"/ProbeMatches";
 
@@ -1534,7 +1553,7 @@ __wsdd__Resolve(struct soap *soap, struct wsdd__ResolveType *Resolve)
   else
   {
     int err;
-    int (*fpost)(struct soap*, const char*, const char*, int, const char*, const char*, size_t);
+    int (*fpost)(struct soap*, const char*, const char*, int, const char*, const char*, ULONG64);
     const char *MessageID = soap_wsa_rand_uuid(soap);
     const char *Action = SOAP_NAMESPACE_OF_wsdd"/ResolveMatches";
 
